==> v0.1.tar.gz: rainynite-core/include/core/context.h <==
/*
 *  context.h - Context
 *  Copyright (C) 2017 caryoscelus
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CORE__CONTEXT_H__50E71540
#define __CORE__CONTEXT_H__50E71540

#include <memory>

#include <boost/any.hpp>
#include <boost/signals2/signal.hpp>

#include <core/time/time_period.h>

namespace core {

class Document;
class AbstractValue;

class Context {
public:
    explicit Context() = default;
    explicit Context(std::weak_ptr<Document> document_);
    Context(Context const& context_);
    Context(Context&& context_) = default;
    Context& operator=(Context const& context_) = default;
    Context& operator=(Context&& context_) = default;
    virtual ~Context();
public:
    inline std::shared_ptr<Document> get_document() const {
        return document.lock();
    }
    inline Time get_time() const {
        return time;
    }
    inline void set_time(Time time_) {
        time = time_;
        changed_time(time);
    }
    inline void set_frames(double frames) {
        time.set_frames(frames);
        changed_time(time);
    }
    inline void set_seconds(double seconds) {
        time.set_seconds(seconds);
        changed_time(time);
    }
    inline void to_start() {
        set_time(time_period.get_first());
    }
    inline void to_end() {
        set_time(time_period.get_last());
    }
    inline TimePeriod get_period() const {
        return time_period;
    }
    inline boost::any get_render_settings() const {
        return render_settings;
    }
    inline boost::any& mod_render_settings() {
        return render_settings;
    }
    inline Time::fps_type get_fps() {
        return fps;
    }
    inline void set_fps(Time::fps_type fps_) {
        fps = fps_;
        time.set_fps(fps);
        time_period.set_fps(fps);
    }
    inline void set_active_node(std::shared_ptr<AbstractValue> node) {
        if (node == active_node)
            return;
        active_node = node;
        changed_active_node(node);
    }
public:
    boost::signals2::signal<void(Time)> changed_time;
    boost::signals2::signal<void(std::shared_ptr<AbstractValue>)> changed_active_node;
private:
    std::weak_ptr<Document> document;
    std::shared_ptr<AbstractValue> active_node;
    Time::fps_type fps = 1;
    Time time;
    TimePeriod time_period;
    boost::any render_settings;
};

} // namespace core

#endif

==> v0.3.tar.gz: rainynite-core/include/core/context.h <==
/*
 *  context.h - Context
 *  Copyright (C) 2017 caryoscelus
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __CORE__CONTEXT_H__50E71540
#define __CORE__CONTEXT_H__50E71540

#include <memory>

#include <boost/any.hpp>
#include <boost/signals2/signal.hpp>

#include <core/time/time_period.h>

namespace core {

class Document;
template <typename>
class Value;

class Context {
public:
    explicit Context() = default;
    explicit Context(std::weak_ptr<Document> document_);
    Context(Context const& context_);
    Context(Context&& context_) = default;
    Context& operator=(Context const& context_) = default;
    Context& operator=(Context&& context_) = default;
    virtual ~Context();
public:
    inline std::shared_ptr<Document> get_document() const {
        return document.lock();
    }
    inline Time get_time() const {
        return time;
    }
    inline void set_time(Time time_) {
        time = time_;
        changed_time(time);
    }
    inline void set_frames(double frames) {
        time.set_frames(frames);
        changed_time(time);
    }
    inline void set_seconds(double seconds) {
        time.set_seconds(seconds);
        changed_time(time);
    }
    inline void to_start() {
        set_time(get_period().get_first());
    }
    inline void to_end() {
        set_time(get_period().get_last());
    }
    void set_period(TimePeriod const& period);
    TimePeriod get_period() const;
    inline boost::any get_render_settings() const {
        return render_settings;
    }
    inline boost::any& mod_render_settings() {
        return render_settings;
    }
    inline Time::fps_type get_fps() {
        return fps;
    }
    void set_fps(Time::fps_type fps_);
public:
    boost::signals2::signal<void(Time)> changed_time;
private:
    std::weak_ptr<Document> document;
    Time::fps_type fps = 1;
    Time time;
    std::shared_ptr<Value<TimePeriod>> time_period;
    boost::any render_settings;
};

} // namespace core

#endif
